From b946b05044264a825c2f62b92e1ac859ef0b3f3e Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <daniel@yesql.se>
Date: Tue, 10 Apr 2018 22:18:38 +0200
Subject: [PATCH] Remove -f option from pg_verify_checksum

There is currently no way to turn on/off checksums on a cluster
outside of initdb, so the -f options makes little sense as it was
intended for the case where checksums could be flipped. Remove -f
until the patch for online checksums land.
---
 doc/src/sgml/ref/pg_verify_checksums.sgml         | 9 ---------
 src/bin/pg_verify_checksums/pg_verify_checksums.c | 9 ++-------
 2 files changed, 2 insertions(+), 16 deletions(-)

diff --git a/doc/src/sgml/ref/pg_verify_checksums.sgml b/doc/src/sgml/ref/pg_verify_checksums.sgml
index 463ecd5e1b..5879dff83d 100644
--- a/doc/src/sgml/ref/pg_verify_checksums.sgml
+++ b/doc/src/sgml/ref/pg_verify_checksums.sgml
@@ -52,15 +52,6 @@ PostgreSQL documentation
       </listitem>
      </varlistentry>
 
-     <varlistentry>
-      <term><option>-f</option></term>
-      <listitem>
-       <para>
-        Force check even if checksums are disabled on cluster.
-       </para>
-      </listitem>
-     </varlistentry>
-
      <varlistentry>
       <term><option>-d</option></term>
       <listitem>
diff --git a/src/bin/pg_verify_checksums/pg_verify_checksums.c b/src/bin/pg_verify_checksums/pg_verify_checksums.c
index ddbd7fa33c..d472f1291c 100644
--- a/src/bin/pg_verify_checksums/pg_verify_checksums.c
+++ b/src/bin/pg_verify_checksums/pg_verify_checksums.c
@@ -42,7 +42,6 @@ usage()
 	printf(_("  %s [OPTION] [DATADIR]\n"), progname);
 	printf(_("\nOptions:\n"));
 	printf(_(" [-D] DATADIR    data directory\n"));
-	printf(_("  -f,            force check even if checksums are disabled\n"));
 	printf(_("  -r relfilenode check only relation with specified relfilenode\n"));
 	printf(_("  -d             debug output, listing all checked blocks\n"));
 	printf(_("  -V, --version  output version information, then exit\n"));
@@ -202,7 +201,6 @@ int
 main(int argc, char *argv[])
 {
 	char	   *DataDir = NULL;
-	bool		force = false;
 	int			c;
 	bool		crc_ok;
 
@@ -224,7 +222,7 @@ main(int argc, char *argv[])
 		}
 	}
 
-	while ((c = getopt(argc, argv, "D:fr:d")) != -1)
+	while ((c = getopt(argc, argv, "D:r:d")) != -1)
 	{
 		switch (c)
 		{
@@ -234,9 +232,6 @@ main(int argc, char *argv[])
 			case 'D':
 				DataDir = optarg;
 				break;
-			case 'f':
-				force = true;
-				break;
 			case 'r':
 				if (atoi(optarg) <= 0)
 				{
@@ -292,7 +287,7 @@ main(int argc, char *argv[])
 		exit(1);
 	}
 
-	if (ControlFile->data_checksum_version == 0 && !force)
+	if (ControlFile->data_checksum_version == 0)
 	{
 		fprintf(stderr, _("%s: data checksums are not enabled in cluster.\n"), progname);
 		exit(1);
-- 
2.14.1.145.gb3622a4ee

